Welcome to dojo-ds's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: Contents (Overview):

   installation
   usage
   contributing
   authors

..    readme
..    history
   
.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   dojo_ds

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
